@@ -10,7 +10,7 @@
 #' 
 #' @return An abbreviated \code{data.frame} of the SWMP metadata for the requested site
 #' 
-#' @details This function retrieves data from the CDMO web services.  The computer making the request must have a registered IP address.  Visit the CDMO web services page for more information: \url{http://cdmo.baruch.sc.edu/webservices.cfm}. This function is the CDMO equivalent of \code{NERRFilterStationCodesXMLNew}.
+#' @details This function retrieves data from the CDMO web services.  The computer making the request must have a registered IP address.  Visit the CDMO web services page for more information: \url{https://cdmo.baruch.sc.edu/webservices.cfm}. This function is the CDMO equivalent of \code{NERRFilterStationCodesXMLNew}.
 #' 
 #' @examples
 #' \dontrun{
@@ -22,7 +22,7 @@
 site_codes_ind <- function(nerr_site_id){
   
   # access CDMO web services
-  serv <- "http://cdmo.baruch.sc.edu/webservices2/requests.cfc?wsdl"
+  serv <- "https://cdmo.baruch.sc.edu/webservices2/requests.cfc?wsdl"
   
   # get all station codes
   reply <- httr::GET(
@@ -40,4 +40,4 @@ site_codes_ind <- function(nerr_site_id){
   # return output
   return(out)
   
-}
\ No newline at end of file
+}
